@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 #
 # Copyright (C) 2010 Radim Rehurek <radimrehurek@seznam.cz>
-# Licensed under the GNU LGPL v2.1 - http://www.gnu.org/licenses/lgpl.html
+# Licensed under the GNU LGPL v2.1 - https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
 
 """Calculate topic coherence for topic models. This is the implementation of the four stage topic coherence pipeline
 from the paper `Michael Roeder, Andreas Both and Alexander Hinneburg: "Exploring the space of topic coherence measures"
@@ -132,8 +132,7 @@ class CoherenceModel(interfaces.TransformationABC):
         model : :class:`~gensim.models.basemodel.BaseTopicModel`, optional
             Pre-trained topic model, should be provided if topics is not provided.
             Currently supports :class:`~gensim.models.ldamodel.LdaModel`,
-            :class:`~gensim.models.ldamulticore.LdaMulticore`, :class:`~gensim.models.wrappers.ldamallet.LdaMallet` and
-            :class:`~gensim.models.wrappers.ldavowpalwabbit.LdaVowpalWabbit`.
+            :class:`~gensim.models.ldamulticore.LdaMulticore`.
             Use `topics` parameter to plug in an as yet unsupported model.
         topics : list of list of str, optional
             List of tokenized topics, if this is preferred over model - dictionary should be provided.
