@@ -3,14 +3,13 @@
 #
 # Author: Gensim Contributors
 # Copyright (C) 2018 RaRe Technologies s.r.o.
-# Licensed under the GNU LGPL v2.1 - http://www.gnu.org/licenses/lgpl.html
+# Licensed under the GNU LGPL v2.1 - https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
 
 """This module implements word vectors, and more generally sets of vectors keyed by lookup tokens/ints,
  and various similarity look-ups.
 
 Since trained word vectors are independent from the way they were trained (:class:`~gensim.models.word2vec.Word2Vec`,
-:class:`~gensim.models.fasttext.FastText`,
-:class:`~gensim.models.wrappers.varembed.VarEmbed` etc), they can be represented by a standalone structure,
+:class:`~gensim.models.fasttext.FastText` etc), they can be represented by a standalone structure,
 as implemented in this module.
 
 The structure is called "KeyedVectors" and is essentially a mapping between *keys*
@@ -518,7 +517,7 @@ class KeyedVectors(utils.SaveLoad):
             elif not ignore_missing:
                 raise KeyError(f"Key '{key}' not present in vocabulary")
 
-        if(total_weight > 0):
+        if total_weight > 0:
             mean = mean / total_weight
         if post_normalize:
             mean = matutils.unitvec(mean).astype(REAL)
@@ -593,7 +592,7 @@ class KeyedVectors(utils.SaveLoad):
 
         in_vocab_mask = np.zeros(len(keys), dtype=bool)
         for idx, key in enumerate(keys):
-            if key in self:
+            if key in self.key_to_index:
                 in_vocab_mask[idx] = True
 
         # add new entities to the vocab
@@ -919,10 +918,8 @@ class KeyedVectors(utils.SaveLoad):
 
         When using this code, please consider citing the following papers:
 
-        * `Ofir Pele and Michael Werman "A linear time histogram metric for improved SIFT matching"
-          <http://www.cs.huji.ac.il/~werman/Papers/ECCV2008.pdf>`_
-        * `Ofir Pele and Michael Werman "Fast and robust earth mover's distances"
-          <https://ieeexplore.ieee.org/document/5459199/>`_
+        * `Rémi Flamary et al. "POT: Python Optimal Transport"
+          <https://jmlr.org/papers/v22/20-451.html>`_
         * `Matt Kusner et al. "From Word Embeddings To Document Distances"
           <http://proceedings.mlr.press/v37/kusnerb15.pdf>`_.
 
@@ -943,7 +940,7 @@ class KeyedVectors(utils.SaveLoad):
 
         Warnings
         --------
-        This method only works if `pyemd <https://pypi.org/project/pyemd/>`_ is installed.
+        This method only works if `POT <https://pypi.org/project/POT/>`_ is installed.
 
         If one of the documents have no words that exist in the vocab, `float('inf')` (i.e. infinity)
         will be returned.
@@ -951,12 +948,11 @@ class KeyedVectors(utils.SaveLoad):
         Raises
         ------
         ImportError
-            If `pyemd <https://pypi.org/project/pyemd/>`_  isn't installed.
+            If `POT <https://pypi.org/project/POT/>`_  isn't installed.
 
         """
-        # If pyemd C extension is available, import it.
-        # If pyemd is attempted to be used, but isn't installed, ImportError will be raised in wmdistance
-        from pyemd import emd
+        # If POT is attempted to be used, but isn't installed, ImportError will be raised in wmdistance
+        from ot import emd2
 
         # Remove out-of-vocabulary words.
         len_pre_oov1 = len(document1)
@@ -1003,12 +999,12 @@ class KeyedVectors(utils.SaveLoad):
                 d[idx] = freq / float(doc_len)  # Normalized word frequencies.
             return d
 
-        # Compute nBOW representation of documents. This is what pyemd expects on input.
+        # Compute nBOW representation of documents. This is what POT expects on input.
         d1 = nbow(document1)
         d2 = nbow(document2)
 
         # Compute WMD.
-        return emd(d1, d2, distance_matrix)
+        return emd2(d1, d2, distance_matrix)
 
     def most_similar_cosmul(
             self, positive=None, negative=None, topn=10, restrict_vocab=None
@@ -1168,7 +1164,7 @@ class KeyedVectors(utils.SaveLoad):
 
     def distances(self, word_or_vector, other_words=()):
         """Compute cosine distances from given word or vector to all words in `other_words`.
-        If `other_words` is empty, return distance between `word_or_vectors` and all words in vocab.
+        If `other_words` is empty, return distance between `word_or_vector` and all words in vocab.
 
         Parameters
         ----------
@@ -1253,7 +1249,7 @@ class KeyedVectors(utils.SaveLoad):
             Similarities between `ws1` and `ws2`.
 
         """
-        if not(len(ws1) and len(ws2)):
+        if not (len(ws1) and len(ws2)):
             raise ZeroDivisionError('At least one of the passed list is empty.')
         mean1 = self.get_mean_vector(ws1, pre_normalize=False)
         mean2 = self.get_mean_vector(ws2, pre_normalize=False)
